pub struct SecretSendContent {
pub request_id: OwnedTransactionId,
pub secret: String,
pub secret_name: Option<SecretName>,
/* private fields */
}Expand description
The m.secret.send event content.
Sent by a client to share a secret with another device, in response to an
m.secret.request event. It must be encrypted as an m.room.encrypted
event, then sent as a to-device event.
Fields
request_id: OwnedTransactionIdThe ID of the request that this a response to.
secret: StringThe contents of the secret.
secret_name: Option<SecretName>The name of the secret, typically not part of the event but can be
inserted when processing m.secret.send events so other event consumers
know which secret this event contains.
Implementations
Sourceimpl SecretSendContent
impl SecretSendContent
Sourcepub fn new(request_id: OwnedTransactionId, secret: String) -> Self
pub fn new(request_id: OwnedTransactionId, secret: String) -> Self
Create a new m.secret.send content.